@@ -22,7 +22,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
-#include <_stdint.h>
+#include <stdint.h>
 #include <stdlib.h>
 #include <time.h>
 #include <fcntl.h>
