@@ -16,8 +16,9 @@
  *                                                                           *
  *  You should have received a copy of the GNU Library General Public        *
  *  License along with this program; see the file COPYING.LIB.  If not,      *
- *  write to the Free Software Foundation, Inc., 59 Temple Place -           *
- *  Suite 330,  Boston, MA 02111-1307, USA.                                  *
+ *  write to the
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA  02110-1301  USA
  *                                                                           *
  *****************************************************************************/
 
@@ -52,7 +53,7 @@
      0x03 = Endcode   for a command
  */
 
-#define _BSD_SOURCE
+#define _DEFAULT_SOURCE
 
 #include "config.h"
 
@@ -62,31 +63,18 @@
 #include <sys/types.h>
 
 #include <fcntl.h>
-#include <unistd.h>
 #include <stdlib.h>
 
 #include <gphoto2/gphoto2-port-log.h>
 #include <gphoto2/gphoto2-library.h>
 #include <gphoto2/gphoto2-result.h>
 
+#include "libgphoto2/i18n.h"
+
 #include "crctab.h"
-
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
-
 #include "hp215.h"
 
+
 enum hp215_cmd {
 	SET_TIME			= 0x86,
 	SET_TIME_AS_STR			= 0x87,
@@ -256,7 +244,7 @@ hp_rcv_ack (Camera *cam, char *ackval)
 static int
 decode_u32(unsigned char **msg, int *msglen, unsigned int *val) {
 	unsigned int x = 0,i;
-
+	*val = 0;
 	for (i=0;i<8;i++) {
 		if (!*msglen)
 			return GP_ERROR;
@@ -272,7 +260,7 @@ decode_u32(unsigned char **msg, int *msglen, unsigned int *val) {
 static int
 decode_u16(unsigned char **msg, int *msglen, unsigned short *val) {
 	unsigned int x = 0,i;
-
+	*val = 0;
 	for (i=0;i<4;i++) {
 		if (!*msglen)
 			return GP_ERROR;
@@ -349,20 +337,34 @@ hp_send_command_and_receive_blob(
 		*msglen = replydatalen;
 		*msg = malloc (replydatalen);
 		ret = gp_port_read (camera->port, (char*)*msg, replydatalen);
-		if (ret < GP_OK)
+		if (ret < GP_OK) {
+			free (*msg);
+			*msg = NULL;
 			return ret;
+		}
 		ret = gp_port_read (camera->port, &eot, 1);
-		if (ret < GP_OK)
+		if (ret < GP_OK) {
+			free (*msg);
+			*msg = NULL;
 			return ret;
-		if (ret != 1)
+		}
+		if (ret != 1) {
+			free (*msg);
+			*msg = NULL;
 			return GP_ERROR_IO;
+		}
 		if (eot != EOT) {
+			free (*msg);
+			*msg = NULL;
 			gp_log (GP_LOG_ERROR, "hp215", "read %02x instead of expected 04", eot);
 			return GP_ERROR_IO;
 		}
 		ackret = hp_send_ack (camera);
-		if (ackret < GP_OK)
+		if (ackret < GP_OK) {
+			free (*msg);
+			*msg = NULL;
 			return ackret;
+		}
 	} else {
 		/* short reply - normal mode, do not copy E0 E0  */
 		*msg = malloc (replydatalen-2);
@@ -370,8 +372,7 @@ hp_send_command_and_receive_blob(
 		memcpy (*msg, msgbuf+5, replydatalen-2);
 	}
 	gp_log (GP_LOG_DEBUG, "hp215", "Read Blob: retcode is %04x", *retcode);
-	gp_log (GP_LOG_DEBUG, "hp215", "Read Blob: argument block is:");
-	gp_log_data ("hp215", (char*)*msg, *msglen);
+	GP_LOG_DATA ((char*)*msg, *msglen, "Read Blob: argument block is:");
 	return GP_OK;
 }
 
@@ -401,7 +402,7 @@ hp_get_timeDate_cam (Camera *cam, char *txtbuffer, size_t txtbuffersize)
 		gp_log (GP_LOG_ERROR, "hp215", "too short reply block, %d bytes", msglen);
 		return GP_ERROR_IO;
 	}
-	
+
 	memcpy (datebuf, msg, 15);
 	gp_log (GP_LOG_DEBUG, "hp215", "0f: %02x", msg[0x0f] & 0x7f);
 	gp_log (GP_LOG_DEBUG, "hp215", "10: %02x", msg[0x10] & 0x7f);
@@ -579,19 +580,24 @@ get_info_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	free (buf);
 	if (ret < GP_OK)
 		return ret;
-	if (msglen < 2)
+
+	if (msglen < 2) {
+		free (msg);
 		return GP_ERROR_IO;
+	}
 
 /*
 0000  80 80 80 85 86 85-84 84 30 31 2f 30 32 2f  ..........01/02/
 0010  30 30 20 31 34 3a 34 38-00 80 81 80 80 80 80 81  00 14:48........
 0020  88 89 84 81 80 80 80 80-80 81 00 00 00 00 00 00  ................
-0030  00 00 00 00 00 00      -                         ......          
+0030  00 00 00 00 00 00      -                         ......
  */
 	xmsg = msg;
 	ret = decode_u32(&xmsg, &msglen, &val);
-	if (ret < GP_OK)
+	if (ret < GP_OK) {
+		free (msg);
 		return ret;
+	}
 	memset (info, 0, sizeof(*info));
 	info->file.fields = GP_FILE_INFO_SIZE;
 	info->file.size = val;
@@ -604,8 +610,10 @@ get_info_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	msglen	-= 2;
 
 	ret = decode_u32(&xmsg, &msglen, &val);
-	if (ret < GP_OK)
+	if (ret < GP_OK) {
+		free (msg);
 		return ret;
+	}
 	info->preview.fields = GP_FILE_INFO_SIZE;
 	info->preview.size = val;
 
@@ -684,7 +692,7 @@ get_shoot_mode_table (Camera *camera) {
 	if (ret < GP_OK) return ret;
 	ret = decode_u32(&xmsg, &msglen, &val3);
 	if (ret < GP_OK) return ret;
-	
+
 	gp_log (GP_LOG_DEBUG, "hp215", "shootmode table 0x%08x, 0x%08x, 0x%08x", val1, val2, val3);
 
 	cnt = val1+val2;
