@@ -31,22 +31,11 @@
 #include <string.h>
 #include <gphoto2/gphoto2.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
 
 #include "library.h"
 
+
 #define GP_MODULE "coolshot"
 
 #define TIMEOUT	      2000
