@@ -31,7 +31,7 @@
 
 #include <gphoto2/gphoto2.h>
 #include <gphoto2/gphoto2-port.h>
-#include <gamma.h>
+#include <libgphoto2/gamma.h>
 
 
 #include "sonix.h"
