@@ -23,9 +23,6 @@
 #include <fcntl.h>
 #include <string.h>
 #include <math.h>
-#ifdef OS2
-#include <db.h>
-#endif
 
 #include <gphoto2/gphoto2.h>
 #include <gphoto2/gphoto2-port.h>
