@@ -1,27 +1,9 @@
 var gphoto2_filesys_8c =
 [
-    [ "_CameraFilesystemFile", "struct__CameraFilesystemFile.html", "struct__CameraFilesystemFile" ],
-    [ "_CameraFilesystemFolder", "struct__CameraFilesystemFolder.html", "struct__CameraFilesystemFolder" ],
-    [ "_CameraFilesystem", "struct__CameraFilesystem.html", "struct__CameraFilesystem" ],
-    [ "_", "gphoto2-filesys_8c.html#a32a3cf3d9dd914f5aeeca5423c157934", null ],
-    [ "_DEFAULT_SOURCE", "gphoto2-filesys_8c.html#a8fb447618db946a9e2a596d9ea18763f", null ],
-    [ "bindtextdomain", "gphoto2-filesys_8c.html#add6dfc1077058ff26d79cdb18099d58a", null ],
-    [ "CA", "gphoto2-filesys_8c.html#a76d3271d228bb3af694e9b846dda71e3", null ],
-    [ "CC", "gphoto2-filesys_8c.html#a2cd5449536c57828b6873e635b51de72", null ],
-    [ "CL", "gphoto2-filesys_8c.html#a387fbb724c3c697e6eb2bd81a9a0e075", null ],
-    [ "CR", "gphoto2-filesys_8c.html#a721a17344ce386f2aa6c408cbe5b027d", null ],
-    [ "CU", "gphoto2-filesys_8c.html#af452484585d434e4101a92ef4ffd55ca", null ],
-    [ "dcgettext", "gphoto2-filesys_8c.html#a115dd6a6dd9d7a249f6374a7c06deef5", null ],
-    [ "dgettext", "gphoto2-filesys_8c.html#ad24abc7110e1bdf384dc2ef2b63e5d07", null ],
-    [ "gettext", "gphoto2-filesys_8c.html#a83b8be0887dede025766d25e2bb884c6", null ],
-    [ "MIN", "gphoto2-filesys_8c.html#a3acffbd305ee72dcd4593c0d8af64a4f", null ],
-    [ "N_", "gphoto2-filesys_8c.html#a75278405e7f034d2b1af80bfd94675fe", null ],
-    [ "PATH_MAX", "gphoto2-filesys_8c.html#ae688d728e1acdfe5988c7db45d6f0166", null ],
+    [ "_CameraFilesystemFile", "struct__CameraFilesystemFile.html", null ],
+    [ "_CameraFilesystemFolder", "struct__CameraFilesystemFolder.html", null ],
+    [ "_CameraFilesystem", "struct__CameraFilesystem.html", null ],
     [ "PICTURES_TO_KEEP", "gphoto2-filesys_8c.html#a46c32fb69d164f5f877338014825d318", null ],
-    [ "textdomain", "gphoto2-filesys_8c.html#a5f80e8482ab93869489531a8c7ce7006", null ],
-    [ "CameraFilesystemFile", "gphoto2-filesys_8c.html#a91fd5cf4334c4b4c5aebc6f52333ccbf", null ],
-    [ "CameraFilesystemFolder", "gphoto2-filesys_8c.html#a9cb6a3a83e8a6cc6ad93b6422e707d8a", null ],
-    [ "gp_filesystem_append", "gphoto2-filesys_8c.html#aafe39aadfe2259eb5bc3d3de0dd864cc", null ],
     [ "gp_filesystem_count", "gphoto2-filesys_8c.html#a7fdf2e5f1c7fda4b0f7f58f45a33c71c", null ],
     [ "gp_filesystem_delete_all", "gphoto2-filesys_8c.html#a6b6fc659abe86a1724fe6600d112931f", null ],
     [ "gp_filesystem_delete_file", "gphoto2-filesys_8c.html#a4d1424f4d45018dc892a2da792822f0c", null ],
@@ -45,5 +27,6 @@ var gphoto2_filesys_8c =
     [ "gp_filesystem_set_file_noop", "gphoto2-filesys_8c.html#a7ee1e023cac99c0e96d28954bd626b19", null ],
     [ "gp_filesystem_set_funcs", "gphoto2-filesys_8c.html#a6f6d981b8ab1273e8048df66670782ab", null ],
     [ "gp_filesystem_set_info", "gphoto2-filesys_8c.html#a3ffbe7ac58a11c688edd98369741f828", null ],
+    [ "gp_filesystem_set_info_dirty", "gphoto2-filesys_8c.html#a660a952a1107a18da00614d1a48fc2e5", null ],
     [ "gp_filesystem_set_info_noop", "gphoto2-filesys_8c.html#a4e4ea8548673cc56c465ee447dd916f3", null ]
 ];
\ No newline at end of file
