@@ -1,7 +1,5 @@
 var gphoto2_port_info_list_8h =
 [
-    [ "GPPortInfo", "gphoto2-port-info-list_8h.html#a541be7394f5ab48304fe48e5a6cec757", null ],
-    [ "GPPortInfoList", "gphoto2-port-info-list_8h.html#abd6e63f271c916e041be85e7b279374a", null ],
     [ "GPPortType", "gphoto2-port-info-list_8h.html#a0607050fab17d2a8c0cbff5747aadc06", [
       [ "GP_PORT_NONE", "gphoto2-port-info-list_8h.html#a0607050fab17d2a8c0cbff5747aadc06a69a2f40a085ca30689e9adca79304839", null ],
       [ "GP_PORT_SERIAL", "gphoto2-port-info-list_8h.html#a0607050fab17d2a8c0cbff5747aadc06aebfd6b4f7f72955e68a546eab8d6b081", null ],
@@ -12,7 +10,6 @@ var gphoto2_port_info_list_8h =
       [ "GP_PORT_USB_SCSI", "gphoto2-port-info-list_8h.html#a0607050fab17d2a8c0cbff5747aadc06a4b179bbb6f1ffe6cf74fca54aea94f2a", null ],
       [ "GP_PORT_IP", "gphoto2-port-info-list_8h.html#a0607050fab17d2a8c0cbff5747aadc06a36c923c944c7ade4127e9a9984630b98", null ]
     ] ],
-    [ "gp_port_info_get_library_filename", "gphoto2-port-info-list_8h.html#a625daffc59c3fd87b9f3b73b129f3b96", null ],
     [ "gp_port_info_get_name", "gphoto2-port-info-list_8h.html#a9810bfba9c986f4d102cfaf649199f21", null ],
     [ "gp_port_info_get_path", "gphoto2-port-info-list_8h.html#a9736997967ed0bdb2ac0ace4e02df531", null ],
     [ "gp_port_info_get_type", "gphoto2-port-info-list_8h.html#a70f65ef80a59174adfa52c3e199752d4", null ],
@@ -25,9 +22,8 @@ var gphoto2_port_info_list_8h =
     [ "gp_port_info_list_lookup_path", "gphoto2-port-info-list_8h.html#ad925c660b558db82d22c62e8ae09c756", null ],
     [ "gp_port_info_list_new", "gphoto2-port-info-list_8h.html#a311d69766c99ba691b0d8f7bfb725d8a", null ],
     [ "gp_port_info_new", "gphoto2-port-info-list_8h.html#a8677c876b22dc6b4545e92fda9810ed4", null ],
-    [ "gp_port_info_set_library_filename", "gphoto2-port-info-list_8h.html#af1f1553e664584f74724a8825829bc09", null ],
     [ "gp_port_info_set_name", "gphoto2-port-info-list_8h.html#a2784f52a6cddb255967a1400e0e07a9a", null ],
     [ "gp_port_info_set_path", "gphoto2-port-info-list_8h.html#a4621674c74440cc4d68d24e45fc9f148", null ],
     [ "gp_port_info_set_type", "gphoto2-port-info-list_8h.html#a292ba5489b58951ccb1c858afe2f2798", null ],
-    [ "gp_port_message_codeset", "gphoto2-port-info-list_8h.html#ae2595948920409d2002d879475d6e350", null ]
+    [ "gp_port_message_codeset", "gphoto2-port-info-list_8h.html#a50b6aadf6f944f92dd084933170498ea", null ]
 ];
\ No newline at end of file
